==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/GetNetworkFabricTopologyPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkFabricName Name of the Network Fabric.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetNetworkFabricTopologyPlainArgs(
    public val networkFabricName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs.builder()
            .networkFabricName(networkFabricName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetNetworkFabricTopologyPlainArgs].
 */
@PulumiTagMarker
public class GetNetworkFabricTopologyPlainArgsBuilder internal constructor() {
    private var networkFabricName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the Network Fabric.
     */
    @JvmName("obclqpjpmfimlpyo")
    public suspend fun networkFabricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkFabricName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ravouosdgwxchujw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetNetworkFabricTopologyPlainArgs = GetNetworkFabricTopologyPlainArgs(
        networkFabricName = networkFabricName ?: throw PulumiNullFieldException("networkFabricName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/GetNetworkFabricTopologyPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkFabricName Name of the Network Fabric.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetNetworkFabricTopologyPlainArgs(
    public val networkFabricName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkFabricTopologyPlainArgs.builder()
            .networkFabricName(networkFabricName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetNetworkFabricTopologyPlainArgs].
 */
@PulumiTagMarker
public class GetNetworkFabricTopologyPlainArgsBuilder internal constructor() {
    private var networkFabricName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the Network Fabric.
     */
    @JvmName("orgonokclkhpuqhs")
    public suspend fun networkFabricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkFabricName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mfkxvdpgfundegxn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetNetworkFabricTopologyPlainArgs = GetNetworkFabricTopologyPlainArgs(
        networkFabricName = networkFabricName ?: throw PulumiNullFieldException("networkFabricName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
